/******************************************************************************/
/* PCM CTK                                                                    */
/* CD-Like tests                                                              */
/* Read/Write scripts                                                         */
/*                                                                            */
/* SAMPLE SCRIPT                                                              */
/*                                                                            */
/******************************************************************************/

/* RETCODES                                        */
/* 20500 - NO_ERROR == 0                           */
/* 20501 - No parameters                           */
/* 20502 - Cannot change to CD                     */
/* 20503 - Unable to clear CD                      */
/* 20504 - Unable to change to TEST Drive          */
/* 20505 - Unable to write file                    */
/* 20506 - Unable to delete file                   */
/* 20507 - Unable to remove directory              */
/* 20508 -                                         */
/* 20509 -                                         */
/* 20510 - Test not implemented                    */
/* 20511 - Test: command failed                    */
/* 20512 - Test: DDTT FAILURE/ERROR in logfile     */


parse arg arg1 arg2 arg3

CDDRIVE = ""
TESTDRIVE = ""
TestFailed = 'FALSE'

/* This block of code gets the name of the command, for later use. */
parse source . . cmdFullName 
cmdNameOnly = filespec("name",cmdFullName)
cmdDrive = filespec("drive",cmdFullName)
cmdName = substr(cmdNameOnly,1,lastPos('.',cmdNameOnly)-1)


call argument arg1
call argument arg2
   
   if CDDRIVE=""  then do
      call print_usage_exit
   end 
   
   if TESTDRIVE=""  then do
      call print_usage_exit
   end 

say " * Running test REXX script:"||cmdName

/* CALL Tests  */
call test_run

/* Default - RETURN OK */
call test_pass

/* Should not be here in */
exit 0

/******************************************************************************/
/* Process CMD Line arguments                                                 */
/******************************************************************************/
argument: 
  parse arg argum
  if argum\='' then 
  select 
  when pos("/CD=",argum)=1 then 
    CDDRIVE=substr(argum,5,2)
  when pos("/TST=",argum)=1 then 
    TESTDRIVE=substr(argum,6,2)
  otherwise
    call print_usage_exit
  end
return

/******************************************************************************/
/* Print out usage and exit with FAIL                                         */
/******************************************************************************/
print_usage_exit:
   say "PCM CTK test script:"||cmdName
   say "Arguments required: /CD=<CD-Letter>: /TST=<Test-Letter>:"
   exit 20501
return

/******************************************************************************/
/* Format CD, must have test drive from where to execute FORMAT               */
/******************************************************************************/
Clear_Test_Disk:
 call change_to_test_root

 '@FORMAT '||CDDRIVE||' /FS:UDF /V:CTKTEST /Y'
 if RC=\0 then do
   call test_fail 20503 '"@FORMAT '||CDDRIVE||' /FS:UDF /V:CTKTEST /Y" RC='||RC
 end
return 

/******************************************************************************/
/* Change current location to CD root                                         */
/******************************************************************************/
change_to_cd_root:
 
 '@'|| CDDRIVE || ' 2>nul'
 
 if RC\=0 then do
   call test_fail 20502 'Unable to change to drive '||CDDRIVE||' RC= '||RC
 end

 '@CD \'
return

/******************************************************************************/
/* Change current location to TEST root                                       */
/******************************************************************************/
change_to_test_root:
 
 '@'|| TESTDRIVE || ' 2>nul'
 
 if RC=\0 then do
   call test_fail 20504 'Unable to change to TEST drive '||TESTDRIVE||' RC='||RC
 end

 '@CD \'
return


/******************************************************************************/
/* Check TEST Folder. (on CD)                                                 */
/*                                                                            */
/* If 'folder'/'file With same name' is present already, then clear media     */
/* If unable to create file with test folfders name, FAIL                     */
/* If unable to delete file with test folfders name, FAIL                     */
/******************************************************************************/
check_test_folder:
  parse arg FILENAME
  
  call change_to_cd_root
 '@CD '||FILENAME||' 2>nul'
 
 if rc==0 then do
   say 'The directory "'||FILENAME||'" already exists. Clearing CD.'
  '@CD \'
   call Clear_Test_Disk
   call change_to_cd_root
 end 
 
 '@'||'type '||FILENAME||' 1>nul 2>nul'
 if rc==0 then do
   say 'The file named "'||FILENAME||'" already exists. Clearing CD.'
   call Clear_Test_Disk
   call change_to_cd_root
 end 
 else 
 do   
 
   '@echo Can Write ? >'||FILENAME||' 2>nul'
   if rc=\0 then do
      call test_fail 20505 'Unable to write file:'||FILENAME||' RC='||rc
   end
   
   '@del '||FILENAME||' 2>nul'
   if rc=\0 then do
         call test_fail 20506 'Unable to delete file:'||FILENAME||' RC='||rc
   end

 end

return

/******************************************************************************/
/* Remove directory                                                           */
/******************************************************************************/
rem_dir:

 parse arg DIRNAME
  
 '@RMDIR '||DIRNAME
 if rc=\0 then do
    call test_fail 20507 'Unable to delete directory:'||DIRNAME||' RC='||rc
 end
  
return


/******************************************************************************/
/* Print out Fail reason and exit with FAIL                                   */
/******************************************************************************/
test_fail:
  parse arg retcode reason
  say "TEST:"||cmdName||" FAILED REASON:"||reason
  exit retcode
return

/******************************************************************************/
/* Print out Fail reason and remember FAIL                                    */
/******************************************************************************/
test_fail_noexit:
  parse arg retcode reason
  say "TEST:"||cmdName||" FAILED REASON:"||reason
  TestFailed = 'TRUE'
  failretcode = retcode
return

/******************************************************************************/
/* Print out Fail reason and remember FAIL                                    */
/******************************************************************************/
test_end:
  if TestFailed = 'TRUE' then do
     call test_fail failretcode 'Test detected at least one fail.'
  end
  else
  do 
     call test_pass
  end
return



/******************************************************************************/
/* Exit with PASSED                                                           */
/******************************************************************************/
test_pass:
  say "TEST:"||cmdName||" PASSED"
  exit 20500
return 

/******************************************************************************/
/* Following procedures are uniq for each test                                */
/******************************************************************************/

/*
---------------------------------  Cut Here ------------------------------------
                                                                              */
test_run:

  NEWSIZE = arg3
  
  /* Make sure CD drive is mounted, and locked, clear CD if required */
  call check_test_folder 'bigfile.dat'
 
  call change_to_cd_root

  '@'||TESTDRIVE||'\CD-TESTS\TOOLS\bigfile.exe  '||CDDRIVE||'\bigfile.dat '||NEWSIZE

  if rc=\0 then do
      call test_fail 20505 'Unable to write file:'||CDDRIVE||'\bigfile.dat  RC='||rc
  end
  
  '@del '||CDDRIVE||'\bigfile.dat'

  if rc=\0 then do
     call test_fail 20506 'Unable to delete file:'||CDDRIVE||'\bigfile.dat  RC='||rc
  end

  call test_pass

return