/* ------------------------------------------------------------------------- */
/* PRINTDD.CMD - FVT PRINTDD Testcase execution.                             */
/*                                                                           */
/*    Parameters: NONE                                                       */
/*                                                                           */
/*    Carried on: FVT Diskettes and CDROM                                    */
/*                                                                           */
/*    Invocation: from OS/2 full screen prompt \printdd\printdd.cmd          */
/*                                                                           */
/*    Uses OS2 environment variables to determine testcase drive.            */
/*                                                                           */
/* Change History:                                                           */
/* --------------                                                            */
/* 11/20/2003 d4094 - USB Printer test added.                                */
/* 12/18/2003 d4105 - Logfile defect fix.                                    */
/*                                                                           */
/* ------------------------------------------------------------------------- */
'@echo off'
arg parm.1 comments
'cls'
say ''
if left(parm.1,1) = '?' then signal INFO_PLEASE
/* ------------------------------------------------------------------------- */
os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT') /* get OS2 boot drive letter */
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT') /* get testcase drive letter */
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_BOOTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_TESTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end

/* ------------------------------------------------------------------------- */
tstdrv':'
'cd \printdd'
/* ------------------------------------------------------------------------- */

/* d4094 Begin */

/* Prepare */
rc = RXFUNCADD('SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs')
call SysLoadFuncs

/* Strings used */
lpt_str = 'have_lpt'
upr_str = 'have_usbprt' /* USB Printer driver */
IniFile = os2drv||':\OS2\PCMCTK.INI' /* Ini file to store info */
IniApp = "Devices" /* Application tree branch */


/* Printer type selection menu */
RETRY:
say 'PCM CTK: Printer port tests.'
say 'Please select apropriate printer connection type.'
say 
say '1 - LPT'
say '2 - USB (USB stack drivers are required. Attach one USB Printer)'
say '3 - LPT and USB (Test both connections. USB stack drivers are required.)'
say '4 - Skip (USBPRT and LPTPRT tests will be marked as NOTRUN!)'
call CharOut ,'>'
parse pull Action

/* Available selected types */
NeedLPT = 0
NeedUSB = 0

/* Check what has been selected */
SELECT
  WHEN Action=1
     THEN NeedLPT = 1
  WHEN Action=2
     THEN NeedUSB = 1
  WHEN Action=3
     THEN do
       NeedLPT = 1
       NeedUSB = 1
     end
  WHEN Action = 4
     THEN exit
OTHERWISE
  say 'Wrong selection. Press ENTER to retry.'
  '@pause >nul'
  call SysCls
  Signal RETRY
END


/* Call detection routine and detect what is available  */
'@call '||os2drv||':\OS2\rmvf.cmd'

/* Read what is available */
HaveLPT = ReadProfile(lpt_str)
HaveUSBPRT = ReadProfile(upr_str)

/* Set test initial status */
USBTEST = 'NOT RUN'
LPTTEST = 'NOT RUN'
LPTTESTOS2 = 'NOT RUN'
LPTTESTDOS = 'NOT RUN'

/* Execute required tests */
if NeedLPT = 1 then do
  if HaveLPT = 1 then do

    /* Need and detected */
    /* LPT port tests */

    /* Default - FAIL */

    LPTTEST = 'FAIL'
    LPTTESTOS2 = 'FAIL'
    LPTTESTDOS = 'FAIL'

    /* OS2 window */
    'call print1.cmd'
    
    /* DOS window */
    'call print1.bat'

    /* d4105 Begin - added grep options */
    grepchk = '-Ny -r'
    rcx = value('grepopt',grepchk,'OS2ENVIRONMENT');
    /* d4105 End */                                                 


    /* Check DOS result - PASS if logfile present and contains PASSED */
    if stream('prt1dos.log'  ,'c','query size') \= '' then do
      'grep PASSED prt1dos.log > nul'
       if rc = 1 then do
          /* d4105 - Using correct variable : LPTTESTDOS */
          LPTTESTDOS = 'PASS' 
       end /* PASSED found */
    end /* Dos Logfile found */

    /* Check OS2 result - PASS if logfile present and contains PASSED */
    if stream('prt1os.log'  ,'c','query size') \= '' then do
      'grep PASSED prt1os.log > nul'

       if rc = 1 then do

          /* d4105 Begin - Fixed swapped variable names. */
          LPTTESTOS2 = 'PASS' 

          if LPTTESTDOS = 'PASS' then do
             LPTTEST = 'PASS'
          end
          /* d4105 End */

       end /* PASSED found */
    end /* OS Logfile found */
  end /* LPT Found */
  else
  do

    /* Need and not detected */
    say 'LPT port is not detected on system.'
    say 'Test failed.'
    LPTTEST = 'FAIL'
    '@pause'  
  end /* LPT Not found */
end /* LPT Selected */


if NeedUSB then do
  if HaveUSBPRT = 1 then do

    /* USBPRT tests OS2 Window */
    'call uprint1.cmd'

    /* Default - FAIL */
    USBTEST = 'FAIL'

    /* Check DOS result - PASS if logfile present and contains PASSED */
    if stream('prt1usb.log' ,'c','query size') \= '' then do

       /* Tes log found but should not contain errors */
       USBTEST = 'PASS'

       'grep "Unable to open" prt1usb.log > nul'
       if rc > 0 then do
          USBTEST = 'FAIL'
       end

       'grep "DosWrite() rcx=" prt1usb.log > nul'
       if rc > 0 then do
          USBTEST = 'FAIL'
       end

    end /* LOGfile found */
  end /* Have USBPRT */
  else
  do
    /* Need and not detected */
    say 'USBPRT is not detected on system.'
    say 'Test failed.'
    USBTEST = 'FAIL'

    '@pause'  
  end /* No USBPRT */
end /* USB Selected */

/* Write Down results */
echo 'LPT '||LPTTEST||'> pddrslt.log'
echo 'LPTOS2 '||LPTTESTOS2||'>> pddrslt.log'
echo 'LPTDOS '||LPTTESTDOS||'>> pddrslt.log'
echo 'USB '||USBTEST||'>> pddrslt.log'
/* d4094 End */

exit
/*-------------------------------------------------------------------------- */
INFO_PLEASE:
  say '[1;26;45m  ͻ  '
  say '   PRINTDD.CMD - Runs FVT PRINTDD Testcases                           '
  say '                                                                      '
  say '   Parameters: NONE                                                   '
  say '                                                                      '
  say '   Runs both OS2 and DOS versions of printdd testcase.                '
  say '                                                                      '
  say '   Uses OS/2 environment variables to determine testcase drive.       '
  say '  ͼ  [0;40;37m'
  exit

/* d4094 Begin */
/*-------------------------------------------------------------------------- */

/* 
 *                 Write PCM CTK Profile data 
 */

WriteProfile: 
  parse arg WPkey,WPvalue
  retvalue = SysIni(IniFile,IniApp,WPkey,WPvalue)
return retvalue

/* 
 *                 Read PCM CTK Profile data 
 */

ReadProfile: 
  parse arg WPkey

  Value = SysIni(IniFile,IniApp,WPkey)

  if Value = "ERROR:" then do
    say "Failed to retrieve key:["||WPKey||"]"
    exit
  end

  /* Check if data contains null at the end */
  if c2x(substr(Value,length(Value),1))=0 then do
    /* Trim the end */
    Value=left(Value,length(Value)-1)
  end

return Value

/* d4094 End */

