/* REXX - IDE 48 Bit tests */
call rxfuncadd 'SysSleep', 'RexxUtil', 'SysSleep'


'@echo off'
'cls'
parse arg parm comments
if left(parm,1) = '?' then signal INFO_PLEASE

/* Detect test drive */
/* ------------------------------------------------------------------------- */
os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT');       /* get OS2 boot drive */
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT');       /* get testcase drive */
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_BOOTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_TESTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end

/* ------------------------------------------------------------------------- */

/* Name of startup.cmd, startup.b48 */
startcmd = os2drv||':\startup.cmd'
startb48 = os2drv||':\startup.b48'

/* Name of test program to start */
idetest  = tstdrv||':\ide48bit\idetest.exe'

/* Name of this cmd file */
iderun  = tstdrv||':\ide48bit\run.cmd'

/* Check if need to restore startup.cmd after boot */
if left(parm,8) = 'NEXTBOOT' then 
do
   /* Launched from startup.cmd       */
   /* restore startup.cmd to original */
   Say ' * Restoring STARTUP.CMD...'
   'copy '||startb48||' '||startcmd||' >nul'
   MyRC = RC
   if MyRC\=0 then call REPORT_ERROR MyRC 'Error occured while trying to RESTORE startup.cmd'
  
   /* Remove backup */
   'del '||startb48||' >nul'
   MyRC = RC
   if MyRC\=0 then call REPORT_ERROR MyRC 'Error occured while trying to REMOVE startup.b48'

   say '[1;37;45mͻ';
   say ' PLEASE WAIT --- Waiting system startup to complete.                 ';
   say 'ͼ[0;40;37m';
   
   /* Wait some time.. */
   call SysSleep 30;
end

/* ------------------------------------------------------------------------- */
tstdrv':'

/* Launch tests */
'@'||idetest

/* Save return code from tests */
MyRC = RC

if MyRC=7800 then do
  /* Continue with reboot */
  say ' * Reboot pending...'

  /* Check if startup.cmd backup is required */
  if stream(startb48,'c','query exists') = '' then do

     /* backup startup.cmd */
     Say ' * Backing up STARTUP.CMD...'
     'copy '||startcmd||' '||startb48||' >nul'
     MyRC = RC
     if MyRC\=0 then call REPORT_ERROR MyRC 'Error occured while trying to BACKUP startup.cmd'

  end
  else
  do
     Say ' * STARTUP.B48 exists, STARTUP.CMD backup skipped...'
  end

  
  /* Make new startup.cmd */
  'echo REM Execute 137 GB tests. > 'startcmd
  'echo REM Original Startup.cmd will be restored from '||startb48||' >>'||startcmd
  'echo call '||iderun||' NEXTBOOT >>'||startcmd
  
   /* Perform reboot */
   say '[1;37;45mͻ';
   say ' PLEASE WAIT --- Let program reboot system, and continue test.       ';
   say 'ͼ[0;40;37m';
   call SysSleep 30;

   os2drv':\os2\swboot r'

   exit

end
else
do
   if MyRC = 0 then do
      /* Test completed */
      say '[1;37;45mͻ';
      say ' IDE 137Gb limit tests, completed successfully!                      ';
      say 'ͼ[0;40;37m';
   end
   else
   do 
      say '[1;09;41m ***************************************************************[0;40;37m'
      say '[1;09;41m * For some reason IDE 137 GB limit testsfailed.               *[0;40;37m'
      say ' * Return Code was = '||MyRC
      say ' * Check logfile: '||os2drv||':\PCMLOGS\idetest.log for more details.'
      say '[1;09;41m ***************************************************************[0;40;37m'
   end
end


exit

/*-------------------------------------------------------------------------- */
INFO_PLEASE:
say '[1;26;45m  ͻ  '
say '   IDE 137 GB Limit test.                                             '
say '                                                                      '
say '   Parameters: ?        - to display this help                        '
say '               NEXTBOOT - to continue tests after reboot, do NOT      '
say '                          use this parameter, it is used by script!   '
say '                                                                      '
say '   Tests will perform 3 reboots between tests, make sure you save     '
say '   all data before starting this test.                                '
say '                                                                      '
say '   Uses OS/2 environment variables to determine testcase drive.       '
say '  ͼ  [0;40;37m'
exit


/*-------------------------------------------------------------------------- */
REPORT_ERROR:
   parse arg MyRC ErrorString
   say '[1;09;41m ***************************************************************[0;40;37m'
   say ' * '||ErrorString
   say ' * RC = '||MyRC||'. Please fix the problem and restart this test!'
   say '[1;09;41m ***************************************************************[0;40;37m'
   say ' '
exit
return