/* ------------------------------------------------------------------------ */
/* Licensed Materials - Property of IBM                                     */
/*                                                                          */
/* (C) Copyright IBM Corporation 2003. All rights reserved.                 */
/*                                                                          */
/* U.S. Government Users Restricted Rights -- Use, duplication or           */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.        */
/*                                                                          */
/* ------------------------------------------------------------------------ */
/*----------------------------------------------------*/
/* RMVIEW                                             */
/*                                                    */
/*  Parameters: NONE                                  */
/*                                                    */
/* OS2 environment variables determine testcase drive.*/
/* ini file version.                                  */
/*                                                    */
/* Change History:                                    */
/* --------------                                     */
/* 11/20/2003 d4094 - Initial Version                 */
/* 12/12/2003 d4100 - USB Floppy detection            */
/* 12/17/2003 d4106 - Removed printouts               */
/*----------------------------------------------------*/
'@echo off'
arg parm.1 comments
'cls'
say ''
if left(parm.1,1) = '?' then signal INFO_PLEASE

os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT')
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT')
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_BOOTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_TESTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end

rc = RXFUNCADD('SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs')
call SysLoadFuncs

/* Ini file to store info */
IniFile = os2drv||':\OS2\PCMCTK.INI' 
/* Application tree branch */
IniApp = "Devices"

/* Interested devices, by default not found */
par_port = 0
ser_port = 0
floppy   = 0
usbprint = 0
usbprtdriver = 0
/* d4100 Begin */
usbmsd   = 0
usbfloppy = 0
/* d4100 End */

'rmview /HW | rxqueue'

/* 
   Parse RMVIEW's output 
*/

do until queued() = 0
  parse pull hardware
  if word(hardware,1)="PARALLEL_0" then par_port = 1
  if word(hardware,1)="SERIAL_0" then ser_port = 1
  if word(hardware,1)="FLOPPY_0" then floppy = 1
  if subword(hardware,1,2)="USB Printer" then usbprtdriver = 1
  /* d4100 Begin */
  if subword(hardware,1,3)="USB Mass Storage" then usbmsd = 1 
  /* d4100 End */
end

/*
   Detect USB printer.
*/

if usbprtdriver = 1 then
do

  /* USB printer driver detected - now make sure that 
     only one device is attached... */

  /* Count usb printers - will write to INI results */
  '@usbpc'

end 

/* d4100 Begin */
/*
   Detect USB floppy if no legacy floppy found.
*/

if floppy \= 1 then 
do
  if usbmsd = 1 then 
  do
    /* USB MSD present */
    /* Get LOCK status - will write to INI results */
    '@usbflc'
  end
end
/* d4100 End */

lpt_str = 'have_lpt'
com_str = 'have_com'
flp_str = 'have_floppy'
upr_str = 'have_usbprt' /* USB Printer driver */
/* d4100 Begin */
usbmsd_str = 'have_usbmsd'  /* USBMSD Loaded  */
call WriteOneDevice usbmsd_str usbmsd
/* d4100 End */
call WriteOneDevice lpt_str par_port
call WriteOneDevice com_str ser_port
call WriteOneDevice flp_str floppy

/* if USBPC is not executed, need to write usbcount to INI */
if usbprtdriver = 0 then call WriteOneDevice upr_str usbprint

/* ------------------ */
say '--- End detection routine ---'
exit

WriteOneDevice:
parse arg name present
  cnst = "N/A"
  /* d4106 - Removed printouts. 
  say name ':' present 
  */

  /* Set write value */
  if present=1 then 
  do 
    cnst = "1"
  end
  else
  do
    cnst = "0"
  end

  /* Write to ini file */
  Rslt = WriteProfile(name,cnst)

  if Rslt = "ERROR:" then 
  do
    say "Failed to write ini file!"
    return
  end

return

INFO_PLEASE:
say '[1;26;45mͻ'
say ' RMVF.CMD -  Parse hardware list from Resource        '
say ' Manager output.                                      '
say '                                                      '
say ' Parameters: NONE                                     '
say '                                                      '
say ' Gets testcase drive from OS/2 environment variables. '
say 'ͼ[0;40;37m'
exit

/* 
 *                 Write PCM CTK Profile data 
 */

WriteProfile: 
  parse arg WPkey,WPvalue
  retvalue = SysIni(IniFile,IniApp,WPkey,WPvalue)
return retvalue

/* 
 *                 Read PCM CTK Profile data 
 */

ReadProfile: 
  parse arg WPkey

  Value = SysIni(IniFile,IniApp,WPkey)

  if Value = "ERROR:" then do
    say "Failed to retrieve key:["||WPKey||"]"
    exit
  end

  /* Check if data contains null at the end */
  if c2x(substr(Value,length(Value),1))=0 then do
    /* Trim the end */
    Value=left(Value,length(Value)-1)
  end

return Value



